@@ -23,7 +23,7 @@ tscriptname=`basename $0 .sh`
 export PKG=`echo $tscriptname | sed -e 's/\-[^\-]*\-[^\-]*$//'`
 export VER=`echo $tscriptname | sed -e "s/${PKG}\-//" -e 's/\-[^\-]*$//'`
 export REL=`echo $tscriptname | sed -e "s/${PKG}\-${VER}\-//"`
-export PKG2=libgdbm3
+export PKG2=libgdbm4
 export PKG3=libgdbm-devel
 export FULLPKG=${PKG}-${VER}-${REL}
 export FULLPKG2=${PKG2}-${VER}-${REL}
@@ -100,6 +100,8 @@ prep() {
   cd ${topdir} && \
   patch -p0 < ${src_patch2} \
   && mkdirs
+  chmod +x ${srcdir}/CYGWIN-PATCHES/convert-gdbm
+  chmod +x ${srcdir}/CYGWIN-PATCHES/gdbmtools-1.3.22.shar
 )}
 
 conf() {
@@ -108,14 +110,18 @@ conf() {
   ${srcdir}/configure --target=${target} \
   --srcdir=${srcdir} --prefix=${prefix} \
   --exec-prefix=${prefix} --sysconfdir=${sysconfdir} \
-  --libdir=${prefix}/lib --includedir=${prefix}/include
+  --libdir=${prefix}/lib --includedir=${prefix}/include \
+  --mandir=${prefix}/share/man --infodir=${prefix}/share/info
 )}
 
 build() {
   (cd ${objdir} && \
   make CFLAGS="${CFLAGS}" LDFLAGS="${MY_LDFLAGS}" && \
   make progs CFLAGS="${CFLAGS}" LDFLAGS="${MY_LDFLAGS}" && \
-  make info CFLAGS="${CFLAGS}" LDFLAGS="${MY_LDFLAGS}"
+  make info CFLAGS="${CFLAGS}" LDFLAGS="${MY_LDFLAGS}" && \
+  ${srcdir}/CYGWIN-PATCHES/gdbmtools-1.3.22.shar && \
+  bunzip2 dumpgdbm-1.3.22.exe.bz2 && \
+  bunzip2 loadgdbm-1.3.22.exe.bz2
 )}
 
 check() {
@@ -133,11 +139,11 @@ install() {
   make install INSTALL_ROOT=${instdir} BINOWN=${MY_BINOWN} BINGRP=${MY_BINGRP} && \
   make install-compat INSTALL_ROOT=${instdir} BINOWN=${MY_BINOWN} BINGRP=${MY_BINGRP} && \
   make install-progs INSTALL_ROOT=${instdir} BINOWN=${MY_BINOWN} BINGRP=${MY_BINGRP} && \
-  if [ -f ${instdir}${prefix}/info/dir ] ; then \
-    rm ${instdir}${prefix}/info/dir ; \
+  if [ -f ${instdir}${prefix}/share/info/dir ] ; then \
+    rm ${instdir}${prefix}/share/info/dir ; \
   fi && \
-  for dirn in ${prefix}/doc/${PKG}-${VER} ${prefix}/doc/${PKG3}-${VER} \
-    ${prefix}/doc/Cygwin ; do \
+  for dirn in ${prefix}/share/doc/${PKG}-${VER} ${prefix}/share/doc/${PKG3}-${VER} \
+    ${prefix}/share/doc/Cygwin ; do \
     if [ ! -d ${instdir}${dirn} ] ; then \
       mkdir -p ${instdir}${dirn} ; \
     fi ;\
@@ -150,16 +156,25 @@ install() {
   done && \
   if [ ! "x$templist" = "x" ]; then \
     /usr/bin/install -m 644 $templist \
-         ${instdir}${prefix}/doc/${PKG}-${VER} ;
+         ${instdir}${prefix}/share/doc/${PKG}-${VER} ;
     /usr/bin/install -m 644 $templist \
-         ${instdir}${prefix}/doc/${PKG3}-${VER} ;
+         ${instdir}${prefix}/share/doc/${PKG3}-${VER} ;
   fi && \
   cat ${srcdir}/CYGWIN-PATCHES/${PKG}.frag \
     ${srcdir}/CYGWIN-PATCHES/README.frag > \
-    ${instdir}${prefix}/doc/Cygwin/${PKG}-${VER}.README && \
+    ${instdir}${prefix}/share/doc/Cygwin/${PKG}-${VER}.README && \
   cat ${srcdir}/CYGWIN-PATCHES/${PKG3}.frag \
     ${srcdir}/CYGWIN-PATCHES/README.frag > \
-   ${instdir}${prefix}/doc/Cygwin/${PKG3}-${VER}.README && \
+    ${instdir}${prefix}/share/doc/Cygwin/${PKG3}-${VER}.README && \
+  /usr/bin/install -m 755 dumpgdbm-1.3.22.exe \
+    ${instdir}${prefix}/bin/dumpgdbm-1.3.22.exe && \
+  /usr/bin/install -m 755 loadgdbm-1.3.22.exe \
+    ${instdir}${prefix}/bin/loadgdbm-1.3.22.exe && \
+  /usr/bin/install -m 755 ${srcdir}/CYGWIN-PATCHES/convert-gdbm \
+    ${instdir}${prefix}/bin/convert-gdbm && \
+  (cd ${instdir}${prefix}/bin ; \
+    cp dumpgdbm.exe dumpgdbm-1.5.2.exe
+    cp loadgdbm.exe loadgdbm-1.5.2.exe)
 )}
 
 strip() {
@@ -197,19 +212,19 @@ pkg() {
   tar cvjf ${bin_pkg} --exclude="${pnoslash}/bin/*.dll" \
     --exclude="${pnoslash}/include" \
     --exclude="${pnoslash}/lib" \
-    --exclude="${pnoslash}/doc/${PKG3}*" \
-    --exclude="${pnoslash}/doc/Cygwin/${PKG3}*" \
-    --exclude="${pnoslash}/info" \
-    --exclude="${pnoslash}/man" \
+    --exclude="${pnoslash}/share/doc/${PKG3}*" \
+    --exclude="${pnoslash}/share/doc/Cygwin/${PKG3}*" \
+    --exclude="${pnoslash}/share/info" \
+    --exclude="${pnoslash}/share/man" \
     --exclude="${snoslash}" \
     * ;
   tar cvjf ${bin_pkg2} ${pnoslash}/bin/*.dll ;
   tar cvjf ${bin_pkg3} ${pnoslash}/lib \
     ${pnoslash}/include \
-    ${pnoslash}/doc/${PKG3}* \
-    ${pnoslash}/doc/Cygwin/${PKG3}* \
-    ${pnoslash}/info/* \
-    ${pnoslash}/man/* 
+    ${pnoslash}/share/doc/${PKG3}* \
+    ${pnoslash}/share/doc/Cygwin/${PKG3}* \
+    ${pnoslash}/share/info/* \
+    ${pnoslash}/share/man/* 
 )}
 
 spkg() {
